<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hi_IN">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="unfinished">मिटाए</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished">पूर्ण स्क्रीन</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished">स्लाइड शो</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished">निर्यात</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished">नकल करे</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished">पसंदीदा</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished">घड़ी की सुई की दिशा में घुमाए</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished">घड़ी की सुई के विपरीत दिशा में घुमाइए</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="unfinished">वॉलपेपर के रूप में सेट करें</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished">फ़ाइल प्रबंधक में प्रदर्शित करें</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished">फोटो की जानकारी</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="unfinished">पुनःस्थापन करे</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>बेनाम</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>बनाए</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>नया एल्बम</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>मिटाए</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>क्या आप वाकई इस एल्बम को हटाना चाहते हैं?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>कचरा</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>पसंदीदा</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>आयात</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>कचरा</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>पसंदीदा</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>या यहां फोटो लाये</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>सभी आयात करें</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>को आयात करे: </translation>
    </message>
    <message>
        <source>Import</source>
        <translation>आयात</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>सिस्टम डिस्क</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>गैलरी</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>डिस्क व्यस्त है, अब इजेक्ट नहीं कर सकता</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ठीक</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>नयी एल्बम</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>कैन्सल्</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>नज़रअंदाज़ करे</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>एल्बम</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>बदले</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>निर्यात</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>चित्र</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>दस्तावेज़</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>डाउनलोडस</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>डेस्कटॉप</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>चल चित्र</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>संगीत</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>नाम:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>में सहेजें:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>स्वरूप:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>गुणवत्ता:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>संर्च्छित करे</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>अन्य डिरेक्टोरिएस का चयन करें</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ठीक</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>फ़ाइल का नाम खाली नहीं हो सकता</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>पहले से ही मौजूद है। क्या आप इसे बदलना चाहते हैं?</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 ड्राइव</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>रिक्त 1% डिस्क</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>% 1 एन्क्रिप्ट किया गया</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1 आवाज</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>संर्च्छित करे</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>तस्वीरें निर्यात करें</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>मिटाया जा रहा है...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>पुन: र्स्थापित किया जा रहा है ...</translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>मिटाए</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this photo from the album?</source>
        <translation>क्या आप वाकई इस फ़ोटो को एल्बम से हटाना चाहते हैं?</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n photos from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Are you sure you want to delete this video from the album?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n videos from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n items from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>बुनियादी जानकारी</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>विवरण</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>आयात</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>स्लाइड शो</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>नाम बदलें</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>निर्यात</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>मिटाए</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>यंत्र</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>गैलरी</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>एल्बमस</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>नयी एल्बम</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>तस्वीरें</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>पूर्ण स्क्रीन</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>मदद</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>फ़ाइल प्रबंधक में प्रदर्शित करें</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>स्लाइड शो</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>नकल करे</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>वॉलपेपर के रूप में सेट करें</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>घड़ी की सुई की दिशा में घुमाए</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>घड़ी की सुई के विपरीत दिशा में घुमाइए</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>पीछे</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>आगे</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>पसंदीदा</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>नापसंदीदा</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>एल्बम का नाम बदले</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>एल्बम &quot;% 1&quot; निकाला गया</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>सफलतापूर्वक &quot;% 1&quot; में जोड़ा गया</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>आयात सफल रहा</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>आयात असफल रहा</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>निर्यात असफल रहा</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>निर्यात सफल रहा</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>सभी तस्वीरें</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>समयसीमा</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>एल्बमस</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>फुलस्क्रीन / स्लाइड शो से बाहर निकलें</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>शॉर्टकट दिखाएं</translation>
    </message>
    <message>
        <source>View</source>
        <translation>देखना</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>सभी का चयन करे</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>आकार बढ़ाए</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>आकार घटाए</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>नयी एल्बम</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>पृष्ठ ऊपर</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>पृष्ठ नीचे</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>सेटटिंग</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>निर्यात किया जा रहा है...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">मिटाए</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>फ़्लैश</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>प्रकार</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>फाइल का आकार</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>आयाम</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>तिथि  ली</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>तिथि संशोधित</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>एक्सपोजर मोड</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>एक्सपोजर प्रोग्राम</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>एक्सपोजर समय</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>छिद्र</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>केन्द्र लम्बाई</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>आइ एस ओ</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>अधिकतम छिद्र का आकार</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>पैमाइश प्रणाली</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>श्वेत संतुलन</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>फ्लैश कोम्पेनसेसन</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>कैमरा मॉडल</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>लेंस मॉडल</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>रंगीन स्थान</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>टैग</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>सिस्टम डिस्क</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>चयन करे</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>चयन रद्द करे</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>आयत किया गया</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1-%2-%3 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>आयत किया गया</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>पुनःस्थापन करे</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>मिटाए</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>तस्वीरें</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>चल चित्र</translation>
    </message>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>पसंदीदा</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>घड़ी की सुई के विपरीत दिशा में घुमाइए</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>घड़ी की सुई की दिशा में घुमाए</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>निर्यात किया जा रहा है...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>कोई खोज परिणाम नहीं</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>स्लाइड शो</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>खोज का परिणाम</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>देखना</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>पूर्ण स्क्रीन</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>निर्यात</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>पसंदीदा</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>नापसंदीदा</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>घड़ी की सुई की दिशा में घुमाए</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>घड़ी की सुई के विपरीत दिशा में घुमाइए</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>फ़ाइल प्रबंधक में प्रदर्शित करें</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>वॉलपेपर के रूप में सेट करें</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>मिटाए</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>स्लाइड शो</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>नकल करे</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>फोटो की जानकारी</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>एल्बम में जोड़ें</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>एल्बम से निकालें</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>पुनःस्थापन करे</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>नयी एल्बम</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>प्रिंट</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished">दिनों</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished">बुनियादी जानकारी</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation type="unfinished">तिथि संशोधित</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">प्रकार</translation>
    </message>
    <message>
        <source>File size</source>
        <translation type="unfinished">फाइल का आकार</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished">तिथि  ली</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
